summaryrefslogtreecommitdiff
path: root/pjsip/include
diff options
context:
space:
mode:
authorBenny Prijono <bennylp@teluu.com>2008-06-06 14:51:48 +0000
committerBenny Prijono <bennylp@teluu.com>2008-06-06 14:51:48 +0000
commit93c46290dcf20a704b36e66208543ff2bc36e23b (patch)
treee9257512192783ec3163602dfd5c502d7bf85342 /pjsip/include
parent5ac557ce4cbeeca1747e14fbf2769d77d23c332d (diff)
More ticket #485: added TURN support in PJSUA-LIB API
git-svn-id: http://svn.pjsip.org/repos/pjproject/trunk@1990 74dad513-b988-da41-8d7b-12977e46ad98
Diffstat (limited to 'pjsip/include')
-rw-r--r--pjsip/include/pjsua-lib/pjsua.h37
-rw-r--r--pjsip/include/pjsua-lib/pjsua_internal.h1
2 files changed, 29 insertions, 9 deletions
diff --git a/pjsip/include/pjsua-lib/pjsua_internal.h b/pjsip/include/pjsua-lib/pjsua_internal.h
index df981ed8..dfb9f84a 100644
--- a/pjsip/include/pjsua-lib/pjsua_internal.h
+++ b/pjsip/include/pjsua-lib/pjsua_internal.h
@@ -52,6 +52,7 @@ typedef struct pjsua_call
pjsip_evsub *xfer_sub; /**< Xfer server subscription, if this
call was triggered by xfer. */
pjmedia_transport *med_tp; /**< Current media transport. */
+ pj_status_t med_tp_st; /**< Media transport status. */
pjmedia_transport *med_orig; /**< Original media transport */
pj_timer_entry refresh_tm;/**< Timer to send re-INVITE. */
pj_timer_entry hangup_tm; /**< Timer to hangup call. */
diff --git a/pjsip/include/pjsua-lib/pjsua.h b/pjsip/include/pjsua-lib/pjsua.h
index 9f42b9ce..9e9ee2a2 100644
--- a/pjsip/include/pjsua-lib/pjsua.h
+++ b/pjsip/include/pjsua-lib/pjsua.h
@@ -1028,8 +1028,8 @@ typedef struct pjsua_config
/**
* Specify domain name to be resolved with DNS SRV resolution to get the
* address of the STUN servers. Alternatively application may specify
* \a stun_host and \a stun_relay_host instead.
*
* If DNS SRV resolution failed for this domain, then DNS A resolution
* will be performed only if \a stun_host is specified.
@@ -1043,11 +1043,6 @@ typedef struct pjsua_config
pj_str_t stun_host;
/**
- * Specify STUN relay server to be used.
- */
- pj_str_t stun_relay_host;
-
- /**
* Support for adding and parsing NAT type in the SDP to assist
* troubleshooting. The valid values are:
* - 0: no information will be added in SDP, and parsing is disabled.
@@ -3886,9 +3881,33 @@ struct pjsua_media_config
pj_bool_t enable_ice;
/**
- * Enable ICE media relay.
+ * Disable ICE host candidates.
+ */
+ pj_bool_t ice_no_host_cands;
+
+ /**
+ * Enable TURN relay candidate in ICE.
+ */
+ pj_bool_t enable_turn;
+
+ /**
+ * Specify TURN domain name or host name, in in "DOMAIN:PORT" or
+ * "HOST:PORT" format.
+ */
+ pj_str_t turn_server;
+
+ /**
+ * Specify the connection type to be used to the TURN server. Valid
+ * values are PJ_TURN_TP_UDP or PJ_TURN_TP_TCP.
+ *
+ * Default: PJ_TURN_TP_UDP
+ */
+ pj_turn_tp_type turn_conn_type;
+
+ /**
+ * Specify the credential to authenticate with the TURN server.
*/
- pj_bool_t enable_relay;
+ pj_stun_auth_cred turn_auth_cred;
};
@@ -1028,8 +1028,8 @@ typedef struct pjsua_config
/**
* Specify domain name to be resolved with DNS SRV resolution to get the
- * address of the STUN servers. Alternatively application may specify
- * \a stun_host and \a stun_relay_host instead.
+ * address of the STUN server. Alternatively application may specify
+ * \a stun_host instead.
*
* If DNS SRV resolution failed for this domain, then DNS A resolution